function [ Area ] = numint ( f, a, b, n, rule )

% Find area under f(x) between a to b using a quadrature rule
% rule = 'L' :   Left-hand  
%        'R' :  Right-hand  
%        'M' :    Midpoint     
%        'T' : Trapezoidal 
%        'S' :   Simpson's
% Example : Trapezoidal Rule for find the area under 
%            f(x)=x with (a,b)=(0,1) using $n=2$ grid points
% >> numint (@(x)(x), 0, 1, 2, 'T') 

 x = linspace (a, b, n);
dx = max(diff(x))      ;

switch rule
  case 'L' % Left-hand rule
    h = feval (f, x(1:n-1));
    Area = dx*sum(h)

  case 'R' % Right-hand rule
    h = feval (f, x(2:n));
    Area = dx*sum(h)

  case 'M' % Midpoint rule
    h = feval (f, (x(1:n-1) + x(2:n))/2);
    Area = dx*sum(h)

  case 'T' % Trapezoidal rule
    y = feval (f, x);
    h = (y(1:n-1) + y(2:n))/2;
    Area = dx*sum(h)

  case 'S' % Simpson's rule
    if mod(n,1)>0, error('n must be odd'); end

    y = feval (f, x);       

    h(1) = 1 ; h(2:2:n-1) = 4 ; h(n) = 1 ; 
               h(3:2:n-1) = 2 ;
    Area = dx*sum(y.*(h/3))
end





%{
close all; n=100:10:200;
f=inline('(x)'); a=0;b=1;
seqL=[]; seqM=[]; seqR=[]; seqT=[];
for i=1:length(n), 
    seqL=[seqL numint(f,a,b,n(i),'L')];
    seqM=[seqM numint(f,a,b,n(i),'M')];
    seqR=[seqR numint(f,a,b,n(i),'R')];
    seqT=[seqT numint(f,a,b,n(i),'T')];
end
Limit=1/2;
plotLMRT([n;n;n;n]', abs([seqL'-Limit,seqM'-Limit,seqR'-Limit,seqT'-Limit]))
%set(gca,'XScale','log','YScale','log')
%plot(n,seqL-Limit, n,seqM-Limit, n,seqR-Limit, n,seqT-Limit); legend('L','M','R','T')
%}
